summaryrefslogtreecommitdiff
path: root/source3/modules/onefs_acl.c
diff options
context:
space:
mode:
authorGünther Deschner <gd@samba.org>2010-05-18 03:30:40 +0200
committerGünther Deschner <gd@samba.org>2010-05-18 12:30:12 +0200
commit8951c8301ac8436d49e1641b2cc7775dda44d914 (patch)
treec85428c92ec6d4878b5628c83a57049a335b184b /source3/modules/onefs_acl.c
parenta8b01d1f3b4025af7e7a9d8b61deec6156737322 (diff)
downloadsamba-8951c8301ac8436d49e1641b2cc7775dda44d914.tar.gz
samba-8951c8301ac8436d49e1641b2cc7775dda44d914.tar.bz2
samba-8951c8301ac8436d49e1641b2cc7775dda44d914.zip
s3-secdesc: remove "typedef struct security_acl SEC_ACL".
Guenther
Diffstat (limited to 'source3/modules/onefs_acl.c')
-rw-r--r--source3/modules/onefs_acl.c12
1 files changed, 6 insertions, 6 deletions
diff --git a/source3/modules/onefs_acl.c b/source3/modules/onefs_acl.c
index 81ee81e787..112ee43fcd 100644
--- a/source3/modules/onefs_acl.c
+++ b/source3/modules/onefs_acl.c
@@ -232,10 +232,10 @@ onefs_samba_ace_to_ace(struct security_ace * samba_ace, struct ifs_ace * ace,
}
/**
* Convert a SEC_ACL to a struct ifs_security_acl
*/
static bool
-onefs_samba_acl_to_acl(SEC_ACL *samba_acl, struct ifs_security_acl **acl,
+onefs_samba_acl_to_acl(struct security_acl *samba_acl, struct ifs_security_acl **acl,
bool * ignore_aces, int snum)
{
int num_aces = 0;
@@ -287,13 +287,13 @@ err_free:
}
/**
* Convert a struct ifs_security_acl to a SEC_ACL
*/
static bool
-onefs_acl_to_samba_acl(struct ifs_security_acl *acl, SEC_ACL **samba_acl)
+onefs_acl_to_samba_acl(struct ifs_security_acl *acl, struct security_acl **samba_acl)
{
struct security_ace *samba_aces = NULL;
- SEC_ACL *tmp_samba_acl = NULL;
+ struct security_acl *tmp_samba_acl = NULL;
int i, num_aces = 0;
if (!samba_acl)
@@ -612,7 +612,7 @@ onefs_fget_nt_acl(vfs_handle_struct *handle, files_struct *fsp,
struct ifs_security_descriptor *sd = NULL;
DOM_SID owner_sid, group_sid;
DOM_SID *ownerp, *groupp;
- SEC_ACL *dacl, *sacl;
+ struct security_acl *dacl, *sacl;
SEC_DESC *pdesc;
bool alloced = false;
bool new_aces_alloced = false;
@@ -232,10 +232,10 @@ onefs_samba_ace_to_ace(struct security_ace * samba_ace, struct ifs_ace * ace,
}
/**
- * Convert a SEC_ACL to a struct ifs_security_acl
+ * Convert a struct security_acl to a struct ifs_security_acl
*/
static bool
@@ -287,13 +287,13 @@ err_free:
}
/**
- * Convert a struct ifs_security_acl to a SEC_ACL
+ * Convert a struct ifs_security_acl to a struct security_acl
*/
static bool